## 0.6.1rc0 (2024-11-06)

### Fix

- update tiramisu dependency

## 0.6.0 (2024-11-01)

### Fix

- black

## 0.6.0rc0 (2024-10-31)

### Feat

- pyproject.toml
- portage to tiramisu 5.0

### Fix

- only first value
